==> RSTouchscreenNG-0.92.2.zip: RSTouchscreenNG/gulpfile.js <==
var shadow = './shadow';
var target = shadow + '/modules/front2';

var cssSource = './projects/style';

const {series, parallel, task, watch, pipe, src, dest} = require('gulp');
const sass = require('gulp-sass');
const cleanCSS = require('gulp-clean-css');
sass.compiler = require('node-sass');
const shell = require('gulp-shell');

task('compilecss', function () {
  return src('./projects/style/style/**/*.scss')
    .pipe(sass().on('error', sass.logError))
    .pipe(dest('./projects/style/css'))
    .pipe(cleanCSS({compatibility: '*'}))
    .pipe(dest('./projects/style/cssmin'));
})



function copycss () {
  return src([cssSource + '/css/', cssSource + '/fonts/'])
    .pipe(dest(devTarget + '/www/'));
}

function copycssProd1 () {
  return src([cssSource + '/fonts'])
    .pipe(dest(target + '/www'));
}

function copycssProd2 () {
  return src([cssSource + '/cssmin/**/*'])
    .pipe(dest(target + '/www/css/'));
}

task('compileBinding', shell.task('ng build binding'))
task('compileFrontend', shell.task('ng build front-ui'))
task('compilePages', shell.task('ng build pages'))
task('compileAppDev', shell.task('ng build app'))
task('compileAppProd', shell.task('ng build app --prod'))
task('compileRegisterDev', shell.task('ng build register'))
task('compileRegisterProd', shell.task('ng build register --prod'))

let copycssProdFunc = parallel(copycssProd1, copycssProd2)
let compileLibs = series(['compileBinding', 'compileFrontend', 'compilePages'])
let compileDev = series([compileLibs, 'compileAppDev', 'compileRegisterDev'])
let compileProd = series([compileLibs, 'compileAppProd', 'compileRegisterProd'])
let all = series([compileLibs,'compileAppProd', 'compileRegisterProd', 'compilecss', copycssProdFunc])
let alldev = series([compileLibs,'compileAppDev', 'compileRegisterDev', 'compilecss', copycss])
task('compilecss:watch', function () {
  watch('./projects/style/style/**/*.scss', series(['compilecss', copycss]));
})
let cssdev = series(['compilecss', copycss])
let defaultaction = series(['compilecss', copycssProdFunc])

task('copycssProd1', copycssProd1)
task('copycssProd2', copycssProd2)
task('copycssProd', copycssProdFunc)
task('cssdev', cssdev)
task('default', defaultaction)
task('all', all)
task('alldev', alldev)
task('libs', compileLibs)
task('dev', compileDev)
task('prod', compileProd)

==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/gulpfile.js <==
var shadow = './shadow';
var target = shadow + '/modules/front2';

var cssSource = './projects/style';

const {series, parallel, task, watch, pipe, src, dest} = require('gulp');
const cleanCSS = require('gulp-clean-css');
sass_compiler = require('node-sass');
const sass = require('gulp-sass')(sass_compiler);
const shell = require('gulp-shell');

task('compilecss', function () {
  return src('./projects/style/style/**/*.scss')
    .pipe(sass().on('error', sass.logError))
    .pipe(dest('./projects/style/css'))
    .pipe(cleanCSS({compatibility: '*'}))
    .pipe(dest('./projects/style/cssmin'));
})



function copycss () {
  return src([cssSource + '/css/', cssSource + '/fonts/'])
    .pipe(dest(devTarget + '/www/'));
}

function copycssProd1 () {
  return src([cssSource + '/fonts'])
    .pipe(dest(target + '/www'));
}

function copycssProd2 () {
  return src([cssSource + '/cssmin/**/*'])
    .pipe(dest(target + '/www/css/'));
}

task('compileBinding', shell.task('ng build binding'))
task('compileFrontend', shell.task('ng build front-ui'))
task('compilePages', shell.task('ng build pages'))
task('compileAppDev', shell.task('ng build app'))
task('compileAppProd', shell.task('ng build app --prod'))
task('compileRegisterDev', shell.task('ng build register'))
task('compileRegisterProd', shell.task('ng build register --prod'))

let copycssProdFunc = parallel(copycssProd1, copycssProd2)
let compileLibs = series(['compileBinding', 'compileFrontend', 'compilePages'])
let compileDev = series([compileLibs, 'compileAppDev', 'compileRegisterDev'])
let compileProd = series([compileLibs, 'compileAppProd', 'compileRegisterProd'])
let all = series([compileLibs,'compileAppProd', 'compileRegisterProd', 'compilecss', copycssProdFunc])
let alldev = series([compileLibs,'compileAppDev', 'compileRegisterDev', 'compilecss', copycss])
task('compilecss:watch', function () {
  watch('./projects/style/style/**/*.scss', series(['compilecss', copycss]));
})
let cssdev = series(['compilecss', copycss])
let defaultaction = series(['compilecss', copycssProdFunc])

task('copycssProd1', copycssProd1)
task('copycssProd2', copycssProd2)
task('copycssProd', copycssProdFunc)
task('cssdev', cssdev)
task('default', defaultaction)
task('all', all)
task('alldev', alldev)
task('libs', compileLibs)
task('dev', compileDev)
task('prod', compileProd)
